export interface INormalObject {
    [prop: string]: any;
}
export interface ILevelItem {
    path: string[];
    parent?: ILevelItem;
    name: string;
    data?: INormalObject;
    children?: ILevelItem[];
}
export declare const NAME_ROOT_LEVEL = "_ROOT";
export declare const NAME_EMPTY_OBJECT = "_EMPTY";
/**
 * 将传入的对象分解成 item level 标准格式（方便后续 merge 操作）
 * 采用懒加载分解方式，不进行超额的分解，节省计算资源
 *
 * @export
 * @param {INormalObject} obj - 目标对象
 * @param {number} [level=0] - 分解层级
 * @returns {ILevelItem[][]}
 */
export declare function parseLevel(obj: INormalObject, level?: number): {
    levels: ILevelItem[][];
    paths: INormalObject[];
};
/**
 * 重新根据 levels 生成 object 对象，
 * 每个 level item 的 data 属性其实相当于缓存
 *
 * @export
 * @param {ILevelItem[][]} levels - item levels 对象
 * @returns
 */
export declare function regenFromLevels(levels: ILevelItem[][]): INormalObject;
/**
 * 重新根据 levels 生成 object 对象，
 * 每个 level item 的 data 属性其实相当于缓存
 *
 * @export
 * @param {ILevelItem[][]} levels - item levels 对象
 * @returns
 */
export declare function reduceLevels(levels: ILevelItem[][], toStopLevel: number): ILevelItem[][];
export declare function mergeWithLevel(origin: INormalObject, target: INormalObject, reserveLevel: number): INormalObject;
export interface IMergeRule {
    [attr: string]: {
        level: number;
    };
}
